@@ -19,14 +19,9 @@ from ..data.dataloader import create_ddfm_dataloader
 from ..utils.time import TimeIndex
 from ..logger import get_logger
 from .utils import (
-    _check_sktime,
     _get_scaler,
     _get_mean,
     _get_scale,
-    _compute_mx_wx,
-    create_passthrough_transformer,
-    _is_pipeline_fitted,
-    _is_scaler_fitted,
 )
 
 _logger = get_logger(__name__)
@@ -38,77 +33,43 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
     This DataModule handles data loading for Deep Dynamic Factor Models.
     Uses DDFMDataset with windowed sequences for neural network training.
     
-    **Important**: DDFM can handle missing data (NaN values) implicitly:
-    - **DDFM**: Uses state-space model and MCMC procedure to handle missing data through
-      idiosyncratic component estimation
+    **Important**: 
+    - Data must be **preprocessed** before passing to this DataModule (imputation, scaling, etc.)
+    - DDFM can handle missing data (NaN values) implicitly through state-space model and MCMC
+    - Only target series Mx, Wx statistics are computed (for inverse transformation in prediction)
+    - Feature Mx, Wx are not needed since predictions only return target series
     
     **Target Series Handling**:
-    - Target series are **NOT preprocessed** by the feature pipeline to avoid inverse transform issues
-    - Target series are passed through as raw data (no imputation, transformation, or scaling)
-    - This is critical for dynamic factor models where targets are endogenous variables
-    - Only feature columns (non-target) are preprocessed by the pipeline
+    - Target series are passed through as raw data (no preprocessing by this module)
     - Optional `target_scaler` can be used to scale targets separately if needed
-    
-    **Usage Pattern**:
-    - Data can contain NaN values - models will handle them implicitly
-    - Supports target series that are not preprocessed (to avoid inverse transform issues)
-    - If `pipeline=None`, a passthrough transformer is used by default (no-op)
-    - Users can optionally provide their preprocessing pipeline to extract statistics (Mx/Wx)
+    - Target Mx, Wx are computed for inverse transformation during prediction
     
     Parameters
     ----------
     config : DFMConfig
         DFM configuration object
-    pipeline : Any, optional
-        sktime-compatible preprocessing pipeline (e.g., TransformerPipeline) used to extract statistics.
-        
-        **If `preprocessed=True`**: Pipeline is assumed to be already fitted (from preprocessing step).
-        Only used for statistics extraction (no fit/transform calls).
-        
-        **If `preprocessed=False`**: Pipeline is used to preprocess feature columns only.
-        Target columns are excluded from preprocessing.
-        
-        **Note**: Target series are never preprocessed by this pipeline.
     data_path : str or Path, optional
         Path to data file (CSV). If None, data must be provided.
     data : np.ndarray or pd.DataFrame, optional
-        Data array or DataFrame. Can contain NaN values - DDFM will handle them.
+        Preprocessed data array or DataFrame. Data must be preprocessed (imputation, scaling, etc.)
+        before passing to this DataModule. Can contain NaN values - DDFM will handle them.
         If None, data_path must be provided.
     target_series : str or List[str], optional
-        Target series column names. These will **NOT be preprocessed** by the feature pipeline.
-        
-        **Important**: Target series are passed through as raw data to avoid inverse transform issues.
-        This is critical for dynamic factor models where targets are endogenous variables.
-        Only feature columns (non-target) will be preprocessed by the pipeline.
+        Target series column names. These will be used for computing Mx, Wx statistics
+        for inverse transformation during prediction.
         
         Example:
             target_series=['market_forward_excess_returns']  # Single target
             target_series=['target1', 'target2']  # Multiple targets
     target_scaler : str or Any, optional
         Optional scaler for target series. Can be:
-        - `None` (default): Targets are not scaled (raw data passed through)
+        - `None` (default): Targets are not scaled (Mx=0, Wx=1)
         - `'standard'`: StandardScaler for targets
         - `'robust'`: RobustScaler for targets (more robust to outliers)
-        - Scaler instance: Custom scaler object (must be fitted if `preprocessed=True`)
+        - Scaler instance: Custom scaler object (must be fitted)
         
-        **Note**: Even if `target_scaler` is provided, targets are still excluded from
-        the feature preprocessing pipeline. This allows separate scaling of targets
-        while keeping them in original scale for inverse transforms.
-        
-        **Typical usage**: `None` (targets should not be preprocessed to avoid inverse issues)
-    preprocessed : bool, default False
-        Whether data is already preprocessed.
-        
-        **If `True`**:
-        - Data is assumed to be already preprocessed (features are scaled/transformed)
-        - Pipeline is assumed to be already fitted (from preprocessing step)
-        - Pipeline is only used for statistics extraction (no fit/transform calls)
-        - Target series remain in raw form (not preprocessed)
-        
-        **If `False`**:
-        - Pipeline will be used to preprocess feature columns (fit_transform)
-        - Target columns are excluded from preprocessing
-        - Target series remain in raw form
+        **Note**: Target scaler is used to compute Mx, Wx statistics for inverse transformation.
+        Targets themselves remain in raw form in the data.
     time_index : TimeIndex, optional
         Time index for the data. If None and time_index_column is provided,
         time index will be extracted from the data.
@@ -131,54 +92,47 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
     
     Examples
     --------
-    **Basic usage with target series**:
+    **Basic usage with preprocessed data**:
     
     >>> from dfm_python import DDFMDataModule
+    >>> from sktime.transformations.compose import TransformerPipeline
+    >>> from sktime.transformations.series.impute import Imputer
+    >>> from sklearn.preprocessing import StandardScaler
     >>> 
-    >>> dm = DDFMDataModule(
-    ...     config=config,
-    ...     data=df_raw,
-    ...     pipeline=preprocess_pipeline,
-    ...     target_series=['market_forward_excess_returns'],
-    ...     preprocessed=False
-    ... )
-    >>> dm.setup()
-    >>> # Features are preprocessed, targets remain raw
-    
-    **Using preprocessed data with target series**:
-    
+    >>> # Preprocess data first
+    >>> pipeline = TransformerPipeline([
+    ...     ('impute', Imputer(method="ffill")),
+    ...     ('scaler', StandardScaler())
+    ... ])
+    >>> df_preprocessed = pipeline.fit_transform(df_raw)
+    >>> 
+    >>> # Create DataModule with preprocessed data
     >>> dm = DDFMDataModule(
     ...     config=config,
     ...     data=df_preprocessed,  # Already preprocessed
-    ...     pipeline=preprocess_pipeline,  # Already fitted
-    ...     target_series=['target1', 'target2'],
-    ...     preprocessed=True  # Data already preprocessed
+    ...     target_series=['market_forward_excess_returns']
     ... )
     >>> dm.setup()
-    >>> # Features use preprocessed data, targets remain raw
     
     **Using target scaler**:
     
     >>> dm = DDFMDataModule(
     ...     config=config,
-    ...     data=df_raw,
-    ...     pipeline=preprocess_pipeline,
+    ...     data=df_preprocessed,  # Already preprocessed
     ...     target_series=['returns'],
-    ...     target_scaler='robust',  # RobustScaler for targets
-    ...     preprocessed=False
+    ...     target_scaler='robust'  # RobustScaler for targets
     ... )
+    >>> dm.setup()
     """
     
     def __init__(
         self,
         config: Optional[DFMConfig] = None,
         config_path: Optional[Union[str, Path]] = None,
-        pipeline: Optional[Any] = None,
         data_path: Optional[Union[str, Path]] = None,
         data: Optional[Union[np.ndarray, pd.DataFrame]] = None,
         target_series: Optional[Union[str, List[str]]] = None,
         target_scaler: Optional[Union[str, Any]] = None,
-        preprocessed: bool = False,
         time_index: Optional[TimeIndex] = None,
         time: Optional[TimeIndex] = None,  # Legacy parameter name (alias for time_index)
         time_index_column: Optional[Union[str, List[str]]] = None,
@@ -190,7 +144,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
         **kwargs
     ):
         super().__init__()
-        _check_sktime()
         
         # Load config if config_path provided
         if config is None and config_path is not None:
@@ -205,7 +158,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
             )
         
         self.config = config
-        self.pipeline = pipeline
         self.data_path = Path(data_path) if data_path is not None else None
         self.data = data
         # Support both time_index and time (legacy) parameter names
@@ -238,8 +190,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
             self.target_scaler = target_scaler
             self.target_scaler_type = None
         
-        self.preprocessed = preprocessed
-        
         # DDFM-specific parameters
         self.window_size = window_size
         self.stride = stride
@@ -252,8 +202,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
         self.val_dataset: Optional[DDFMDataset] = None
         self.Mx: Optional[np.ndarray] = None
         self.Wx: Optional[np.ndarray] = None
-        self.target_Mx: Optional[np.ndarray] = None
-        self.target_Wx: Optional[np.ndarray] = None
         self.data_processed: Optional[torch.Tensor] = None
         self.data_raw: Optional[pd.DataFrame] = None
     
@@ -261,10 +209,10 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
         """Load and prepare data.
         
         This method handles:
-        - Loading data from file or using provided data
+        - Loading data from file or using provided data (data must be preprocessed)
         - Separating target and feature columns
-        - Preprocessing features (if not preprocessed) or extracting statistics (if preprocessed)
-        - Keeping targets unprocessed (to avoid inverse transform issues)
+        - Computing target Mx, Wx statistics for inverse transformation
+        - Keeping targets in raw form (to avoid inverse transform issues)
         """
         # Load data if not already provided
         if self.data is None:
@@ -338,156 +286,52 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
         # Separate target and feature columns
         all_columns = list(X_df.columns)
         target_cols = [col for col in self.target_series if col in all_columns]
-        feature_cols = [col for col in all_columns if col not in target_cols]
         
-        if self.preprocessed:
-            # Already preprocessed: use data as-is, extract statistics only
-            # Pipeline is assumed to be already fitted (passed from preprocessing step)
-            X_transformed = X_df.copy()
-            
-            # Pipeline is for statistics extraction only (already fitted, no fit/transform)
-            if self.pipeline is not None and feature_cols:
-                # Pipeline should already be fitted - just extract statistics
-                # No fit() call needed - pipeline was fitted during preprocessing
-                scaler = _get_scaler(self.pipeline)
-                if scaler is not None:
-                    feature_values = np.asarray(X_df[feature_cols].values)
-                    self.Mx = _get_mean(scaler, feature_values)
-                    self.Wx = _get_scale(scaler, feature_values)
-                else:
-                    # Fallback: compute from data
-                    feature_values = np.asarray(X_df[feature_cols].values)
-                    self.Mx, self.Wx = _compute_mx_wx(feature_values)
-            elif feature_cols:
-                # No pipeline: compute from data
-                feature_values = np.asarray(X_df[feature_cols].values)
-                self.Mx, self.Wx = _compute_mx_wx(feature_values)
+        # Data is already preprocessed - use as-is
+        X_transformed = X_df.copy()
+        
+        # Compute target Mx, Wx only (for inverse transformation in prediction)
+        # Feature Mx, Wx are not needed since we only return target predictions
+        if target_cols:
+            if self.target_scaler_type is not None:
+                # Create scaler from string type
+                from sklearn.preprocessing import StandardScaler, RobustScaler
+                if self.target_scaler_type == 'standard':
+                    target_scaler_instance = StandardScaler()
+                else:  # 'robust'
+                    target_scaler_instance = RobustScaler()
+                # Fit on raw target data
+                target_scaler_instance.fit(X_df[target_cols])
+                target_values = np.asarray(X_df[target_cols].values)
+                self.Mx = _get_mean(target_scaler_instance, target_values)
+                self.Wx = _get_scale(target_scaler_instance, target_values)
+                self.target_scaler = target_scaler_instance  # Store for later use
+            elif self.target_scaler is not None:
+                # Scaler instance provided - should already be fitted
+                # Just extract statistics (no fit() call needed)
+                target_values = np.asarray(X_df[target_cols].values)
+                self.Mx = _get_mean(self.target_scaler, target_values)
+                self.Wx = _get_scale(self.target_scaler, target_values)
             else:
-                # No features: set to empty
-                self.Mx = np.array([])
-                self.Wx = np.array([])
-            
-            # Target scaler (optional, typically None)
-            # Targets are NOT preprocessed by feature pipeline - they remain raw
-            if target_cols:
-                if self.target_scaler_type is not None:
-                    # Create scaler from string type
-                    from sklearn.preprocessing import StandardScaler, RobustScaler
-                    if self.target_scaler_type == 'standard':
-                        target_scaler_instance = StandardScaler()
-                    else:  # 'robust'
-                        target_scaler_instance = RobustScaler()
-                    # Fit on raw target data
-                    target_scaler_instance.fit(X_df[target_cols])
-                    target_values = np.asarray(X_df[target_cols].values)
-                    self.target_Mx = _get_mean(target_scaler_instance, target_values)
-                    self.target_Wx = _get_scale(target_scaler_instance, target_values)
-                    self.target_scaler = target_scaler_instance  # Store for later use
-                elif self.target_scaler is not None:
-                    # Scaler instance provided - should already be fitted
-                    # Just extract statistics (no fit() call needed)
-                    target_values = np.asarray(X_df[target_cols].values)
-                    self.target_Mx = _get_mean(self.target_scaler, target_values)
-                    self.target_Wx = _get_scale(self.target_scaler, target_values)
-                else:
-                    # No target scaler: targets not preprocessed (Mx=0, Wx=1)
-                    # Targets remain in raw form
-                    self.target_Mx = np.zeros(len(target_cols))
-                    self.target_Wx = np.ones(len(target_cols))
-            else:
-                self.target_Mx = np.array([])
-                self.target_Wx = np.array([])
+                # No target scaler: targets not preprocessed (Mx=0, Wx=1)
+                # Targets remain in raw form
+                self.Mx = np.zeros(len(target_cols))
+                self.Wx = np.ones(len(target_cols))
         else:
-            # Not preprocessed: preprocess features, keep targets as-is
-            if self.pipeline is not None and feature_cols:
-                # Preprocess features only
-                X_features_transformed = self.pipeline.fit_transform(X_df[feature_cols])
-                
-                # Extract feature Mx, Wx
-                scaler = _get_scaler(self.pipeline)
-                if scaler is not None:
-                    feature_values = np.asarray(X_features_transformed.values)
-                    self.Mx = _get_mean(scaler, feature_values)
-                    self.Wx = _get_scale(scaler, feature_values)
-                else:
-                    feature_values = np.asarray(X_features_transformed.values)
-                    self.Mx, self.Wx = _compute_mx_wx(feature_values)
-            elif feature_cols:
-                # No pipeline: compute from data
-                feature_values = np.asarray(X_df[feature_cols].values)
-                self.Mx, self.Wx = _compute_mx_wx(feature_values)
-                X_features_transformed = X_df[feature_cols]
-            else:
-                # No features
-                X_features_transformed = pd.DataFrame()
-                self.Mx = np.array([])
-                self.Wx = np.array([])
-            
-            # Targets: keep as-is (no preprocessing by feature pipeline)
-            # Targets are NOT preprocessed - they remain in raw form
-            if target_cols:
-                X_target = X_df[target_cols].copy()  # Raw target data
-            else:
-                X_target = pd.DataFrame()
-            
-            # Target scaler (optional, typically None)
-            # Even if target_scaler is provided, targets are still excluded from feature pipeline
-            if target_cols:
-                if self.target_scaler_type is not None:
-                    # Create scaler from string type
-                    from sklearn.preprocessing import StandardScaler, RobustScaler
-                    if self.target_scaler_type == 'standard':
-                        target_scaler_instance = StandardScaler()
-                    else:  # 'robust'
-                        target_scaler_instance = RobustScaler()
-                    # Fit on raw target data
-                    target_scaler_instance.fit(X_target)
-                    target_values = np.asarray(X_target.values)
-                    self.target_Mx = _get_mean(target_scaler_instance, target_values)
-                    self.target_Wx = _get_scale(target_scaler_instance, target_values)
-                    self.target_scaler = target_scaler_instance  # Store for later use
-                elif self.target_scaler is not None:
-                    # Scaler instance provided - fit on raw target data
-                    self.target_scaler.fit(X_target)
-                    target_values = np.asarray(X_target.values)
-                    self.target_Mx = _get_mean(self.target_scaler, target_values)
-                    self.target_Wx = _get_scale(self.target_scaler, target_values)
-                else:
-                    # No target scaler: targets not preprocessed (Mx=0, Wx=1)
-                    # Targets remain in raw form
-                    self.target_Mx = np.zeros(len(target_cols))
-                    self.target_Wx = np.ones(len(target_cols))
-            else:
-                self.target_Mx = np.array([])
-                self.target_Wx = np.array([])
-            
-            # Combine features and targets
-            if target_cols:
-                X_transformed = pd.concat([X_features_transformed, X_target], axis=1)
-                # Preserve original column order
-                X_transformed = X_transformed[all_columns]
-            else:
-                X_transformed = X_features_transformed
-        
-        # Combine Mx, Wx in column order (feature + target)
-        if target_cols and self.Mx is not None and self.Wx is not None and self.target_Mx is not None and self.target_Wx is not None:
-            full_Mx = np.zeros(len(all_columns))
-            full_Wx = np.ones(len(all_columns))
-            
-            for i, col in enumerate(all_columns):
-                if col in feature_cols:
-                    feat_idx = feature_cols.index(col)
-                    full_Mx[i] = self.Mx[feat_idx]
-                    full_Wx[i] = self.Wx[feat_idx]
-                elif col in target_cols:
-                    tgt_idx = target_cols.index(col)
-                    full_Mx[i] = self.target_Mx[tgt_idx]
-                    full_Wx[i] = self.target_Wx[tgt_idx]
-            
-            self.Mx = full_Mx
-            self.Wx = full_Wx
+            self.Mx = np.array([])
+            self.Wx = np.array([])
         
         # Convert to torch tensor
+        # Select only numeric columns (exclude datetime and other object types)
+        numeric_cols = X_transformed.select_dtypes(include=[np.number]).columns
+        if len(numeric_cols) < len(X_transformed.columns):
+            excluded_cols = [col for col in X_transformed.columns if col not in numeric_cols]
+            _logger.warning(
+                f"Excluding non-numeric columns from data: {excluded_cols}. "
+                f"These columns will not be used in model training."
+            )
+            X_transformed = X_transformed[numeric_cols]
+        
         X_processed_np = X_transformed.to_numpy()
         self.data_processed = torch.tensor(X_processed_np, dtype=torch.float32)
         
@@ -545,10 +389,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
             )
         return self.Mx, self.Wx
     
-    def get_pipeline(self) -> Any:
-        """Get the preprocessing pipeline used for statistics extraction."""
-        return self.pipeline
-    
     def get_processed_data(self) -> torch.Tensor:
         """Get processed data tensor."""
         if self.data_processed is None:
@@ -567,10 +407,6 @@ class DDFMDataModule(lightning_pl.LightningDataModule):
             )
         return self.data_raw
     
-    def is_data_preprocessed(self) -> bool:
-        """Check if data is already preprocessed."""
-        return self.preprocessed
-    
     def get_target_indices(self) -> List[int]:
         """Get indices of target series columns."""
         if self.data_raw is None:
