@@ -219,7 +219,7 @@ def _compute_mx_wx(data: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
     
     Parameters
     ----------
-    data : np.ndarray
+    data : np.ndarray or pd.DataFrame
         Processed data array (T x N), may contain NaN values
         
     Returns
@@ -235,6 +235,26 @@ def _compute_mx_wx(data: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
     2. Issue a warning recommending data imputation for better results
     3. Continue processing with available data
     """
+    # Convert to numpy array - handle DataFrame, Series, and other types
+    import pandas as pd
+    if isinstance(data, pd.DataFrame):
+        data = data.values
+    elif isinstance(data, pd.Series):
+        data = data.values
+    elif not isinstance(data, np.ndarray):
+        data = np.asarray(data)
+    
+    # Ensure numeric type for isnan check
+    if data.dtype.kind not in ['f', 'i', 'u', 'c']:  # float, int, uint, complex
+        # Try to convert to float
+        try:
+            data = data.astype(float)
+        except (ValueError, TypeError):
+            raise TypeError(
+                f"_compute_mx_wx: Cannot convert data to numeric type. "
+                f"Data type: {type(data)}, dtype: {getattr(data, 'dtype', 'unknown')}"
+            )
+    
     # Check for NaN values
     has_nan = np.any(np.isnan(data))
     if has_nan:
