@@ -81,14 +81,14 @@ from .diagnostics import (
     evaluate_loading_estimation,
 )
 
-# VAE functions are now in encoder.vae
-from ..encoder.vae import (
+# Autoencoder functions are now in encoder.autoencoder
+from ..encoder.autoencoder import (
     extract_decoder_params,
     convert_decoder_to_numpy,
 )
 
 __all__ = [
-    # VAE functions (from encoder.vae)
+    # Autoencoder functions (from encoder.autoencoder)
     'extract_decoder_params',
     'convert_decoder_to_numpy',
     # State-space utilities (includes DDFM utilities)
