@@ -139,26 +139,13 @@ print("\n[Step 3] Creating configuration...")
 # Create series configs
 series_configs = []
 for col in selected_cols:
-    if col == target_col:
-        # Target series
-        series_configs.append(
-            SeriesConfig(
-                series_id=col,
-                frequency="m",  # Assuming monthly
-                transformation="lin",
-                blocks=[DEFAULT_BLOCK_NAME]
-            )
-        )
-    else:
-        # Predictor series
-        series_configs.append(
-            SeriesConfig(
-                series_id=col,
-                frequency="m",
-                transformation="lin",
-                blocks=[DEFAULT_BLOCK_NAME]
-            )
+    # SeriesConfig only needs frequency (transformation and blocks removed)
+    series_configs.append(
+        SeriesConfig(
+            series_id=col,
+            frequency="m"  # Assuming monthly
         )
+    )
 
 # Create blocks config - VAR(1) only
 blocks_config = {
@@ -199,18 +186,13 @@ time_list = [
 time_index = TimeIndex(time_list)
 
 # Create DDFMDataModule with preprocessed data
-# Since data is already preprocessed, use preprocessed=True
-# Pipeline is already fitted, so it will only be used for statistics extraction
+# Data must be preprocessed before passing to DataModule
 # Target series are specified separately - they remain in raw form (not preprocessed)
-# Note: In this tutorial, target is included in preprocessed data, but DDFMDataModule
-# will handle it correctly by extracting it separately
 data_module = DDFMDataModule(
     config=config,
-    data=df_processed,  # Pass DataFrame directly (not .values)
+    data=df_processed,  # Pass DataFrame directly (not .values) - already preprocessed
     time_index=time_index,
-    pipeline=preprocessing_pipeline,  # Already fitted pipeline (for statistics extraction)
-    preprocessed=True,  # Data is already preprocessed
-    target_series=[target_col]  # Specify target series (will be extracted separately)
+    target_series=[target_col]  # Specify target series
 )
 data_module.setup()
 
@@ -252,18 +234,25 @@ X_forecast_history = None
 Z_forecast_history = None
 
 try:
-    # Predict with default horizon
+    # Predict with default horizon (target=None uses DataModule's target_series)
     X_forecast, Z_forecast = model.predict(horizon=6)
     
-    print(f"   Forecast shape: {X_forecast.shape}")
+    print(f"   Forecast shape: {X_forecast.shape} (target series only)")
     print(f"   Factor forecast shape: {Z_forecast.shape}")
-    print(f"   First forecast values (target): {X_forecast[0, -1]:.6f}")
+    # X_forecast now contains only target series (no features)
+    if X_forecast.shape[1] == 1:
+        print(f"   First forecast value (target): {X_forecast[0, 0]:.6f}")
+    else:
+        print(f"   First forecast values (targets): {X_forecast[0, :]}")
     
     # Predict with history parameter (using recent 60 periods)
     X_forecast_history, Z_forecast_history = model.predict(horizon=6, history=60)
     
-    print(f"   Forecast with history shape: {X_forecast_history.shape}")
-    print(f"   First forecast with history (target): {X_forecast_history[0, -1]:.6f}")
+    print(f"   Forecast with history shape: {X_forecast_history.shape} (target series only)")
+    if X_forecast_history.shape[1] == 1:
+        print(f"   First forecast with history (target): {X_forecast_history[0, 0]:.6f}")
+    else:
+        print(f"   First forecast with history (targets): {X_forecast_history[0, :]}")
     
 except ValueError as e:
     print(f"   Prediction failed: {e}")
@@ -300,11 +289,14 @@ try:
     
     # Update model state with new standardized data, then predict
     # Pattern: model.update(X_std).predict(horizon=1)
+    # predict() returns only target series (target=None uses DataModule's target_series)
     X_nowcast, Z_nowcast = model.update(X_new_std).predict(horizon=1)
     
-    # Extract nowcast for target series
-    target_idx = selected_cols.index(target_col)
-    nowcast_value = X_nowcast[0, target_idx]
+    # X_nowcast now contains only target series (no features)
+    if X_nowcast.shape[1] == 1:
+        nowcast_value = X_nowcast[0, 0]
+    else:
+        nowcast_value = X_nowcast[0, :]
     
     print(f"   Nowcast value for {target_col}: {nowcast_value:.6f}")
     print(f"   Nowcast uses VAR(1) factor dynamics")
@@ -312,7 +304,10 @@ try:
     # Alternative: Update and predict separately
     model.update(X_new_std)
     X_nowcast2, Z_nowcast2 = model.predict(horizon=1)
-    nowcast_value2 = X_nowcast2[0, target_idx]
+    if X_nowcast2.shape[1] == 1:
+        nowcast_value2 = X_nowcast2[0, 0]
+    else:
+        nowcast_value2 = X_nowcast2[0, :]
     print(f"   Alternative pattern (separate calls): {nowcast_value2:.6f}")
     
 except (ValueError, AttributeError, IndexError) as e:
