@@ -67,14 +67,20 @@ selected_cols = [
 # Filter to only columns that exist in the data
 selected_cols = [col for col in selected_cols if col in df.columns]
 
-# Filter data (include date column for time index)
-df_processed = df[selected_cols + ["date"]].copy()
+# Filter data (include date column for time index, but separate it early)
+df_with_date = df[selected_cols + ["date"]].copy()
 print(f"   Selected {len(selected_cols)} series (including target)")
 print(f"   Series: {selected_cols[:5]}...")
 
-# Parse date column
-df_processed["date"] = pd.to_datetime(df_processed["date"])
-df_processed = df_processed.sort_values("date")
+# Parse and sort by date column
+df_with_date["date"] = pd.to_datetime(df_with_date["date"])
+df_with_date = df_with_date.sort_values("date")
+
+# Extract date column separately before preprocessing
+date_column = df_with_date["date"].copy()
+
+# Remove date column from data for preprocessing
+df_processed = df_with_date.drop(columns=["date"]).copy()
 
 # Remove rows with all NaN
 df_processed = df_processed.dropna(how='all')
@@ -84,6 +90,7 @@ df_processed = df_processed.dropna(how='all')
 max_periods = 100
 if len(df_processed) > max_periods:
     df_processed = df_processed.iloc[-max_periods:]
+    date_column = date_column.iloc[-max_periods:]
     print(f"   Using last {max_periods} periods for faster execution")
 
 print(f"   Data shape after cleaning: {df_processed.shape}")
@@ -109,14 +116,9 @@ if target_col in df_processed.columns:
     df_processed[target_col] = target_diff
     print(f"   Applied difference transformation to {target_col}")
 
-# Note: date column will be removed by DataModule when time_index_column='date' is used
-# For preprocessing, we need to temporarily remove it to avoid issues with datetime columns
-# Store date column separately for reference (though DataModule will extract it)
-if 'date' in df_processed.columns:
-    # Temporarily remove date column for preprocessing (DataModule will handle it)
-    df_for_preprocessing = df_processed.drop(columns=['date'])
-else:
-    df_for_preprocessing = df_processed
+# Date column is already separated, so df_processed has no date column
+# Use df_processed directly for preprocessing
+df_for_preprocessing = df_processed
 
 # Create simplified preprocessing pipeline: Imputation → Scaling
 # (Transformations already applied manually above)
@@ -152,13 +154,13 @@ if isinstance(df_preprocessed, np.ndarray):
 elif not isinstance(df_preprocessed, pd.DataFrame):
     df_preprocessed = pd.DataFrame(df_preprocessed)
 
-# Add date column back for DataModule to extract (if it exists)
-if 'date' in df_processed.columns:
-    df_preprocessed['date'] = df_processed['date'].values
+# Add date column back for DataModule to extract
+# Date column was separated earlier, so add it back now
+df_preprocessed['date'] = date_column.values
 
 # Ensure output is DataFrame
 if isinstance(df_preprocessed, np.ndarray):
-    df_preprocessed = pd.DataFrame(df_preprocessed, columns=df_processed.columns, index=df_processed.index)
+    df_preprocessed = pd.DataFrame(df_preprocessed, columns=list(df_for_preprocessing.columns) + ['date'], index=df_for_preprocessing.index)
 elif not isinstance(df_preprocessed, pd.DataFrame):
     df_preprocessed = pd.DataFrame(df_preprocessed)
 
@@ -186,26 +188,14 @@ print("\n[Step 3] Creating configuration...")
 # Create series configs
 series_configs = []
 for col in selected_cols:
-    if col == target_col:
-        # Target series - use chg transformation (as per series config)
-        series_configs.append(
-            SeriesConfig(
-                series_id=col,
-                frequency="m",
-                transformation="chg",  # As per KOEQUIPTE.yaml
-                blocks=[DEFAULT_BLOCK_NAME]
-            )
-        )
-    else:
-        # Predictor series - use lin for simplicity
-        series_configs.append(
-            SeriesConfig(
-                series_id=col,
-                frequency="m",
-                transformation="lin",
-                blocks=[DEFAULT_BLOCK_NAME]
-            )
+    # SeriesConfig only needs frequency (transformation and blocks removed)
+    # Transformation is handled by preprocessing pipeline, not SeriesConfig
+    series_configs.append(
+        SeriesConfig(
+            series_id=col,
+            frequency="m"
         )
+    )
 
 # Create blocks config - VAR(1) only
 blocks_config = {
@@ -233,19 +223,14 @@ print(f"   Target series: {target_col}")
 print("\n[Step 4] Creating DataModule...")
 
 # Create DDFMDataModule with preprocessed data
-# Since data is already preprocessed, use preprocessed=True
-# Pipeline is already fitted, so it will only be used for statistics extraction
+# Data must be preprocessed before passing to DataModule
 # Target series are specified separately - they remain in raw form (not preprocessed)
 # time_index_column='date' will extract time index from DataFrame and remove the column
-# Note: In this tutorial, target is included in preprocessed data, but DDFMDataModule
-# will handle it correctly by extracting it separately
 data_module = DDFMDataModule(
     config=config,
-    data=df_processed,  # Pass DataFrame directly (not .values)
+    data=df_processed,  # Pass DataFrame directly (not .values) - already preprocessed
     time_index_column='date',  # Extract time index from 'date' column and exclude it from data
-    pipeline=fitted_pipeline,  # Already fitted pipeline (for statistics extraction)
-    preprocessed=True,  # Data is already preprocessed
-    target_series=[target_col]  # Specify target series (will be extracted separately)
+    target_series=[target_col]  # Specify target series
 )
 data_module.setup()
 
@@ -287,38 +272,35 @@ X_forecast = None
 Z_forecast = None
 X_forecast_history = None
 Z_forecast_history = None
-scaler = _get_fitted_scaler(fitted_pipeline, df_processed)
+# Exclude date column for scaler extraction
+df_for_scaler = df_processed.drop(columns=['date']) if 'date' in df_processed.columns else df_processed
+scaler = _get_fitted_scaler(fitted_pipeline, df_for_scaler)
 
 try:
-    # Predict with default horizon
+    # Predict with default horizon (target=None uses DataModule's target_series)
     X_forecast, Z_forecast = model.predict(horizon=6)
     
-    print(f"   Forecast shape: {X_forecast.shape}")
+    print(f"   Forecast shape: {X_forecast.shape} (target series only)")
     print(f"   Factor forecast shape: {Z_forecast.shape}")
     
-    # Find target index
-    target_idx = selected_cols.index(target_col)
-    print(f"   First forecast value (target {target_col}): {X_forecast[0, target_idx]:.6f}")
+    # X_forecast now contains only target series (no features)
+    if X_forecast.shape[1] == 1:
+        print(f"   First forecast value (target {target_col}): {X_forecast[0, 0]:.6f}")
+    else:
+        print(f"   First forecast values (targets): {X_forecast[0, :]}")
     
-    # Verify inverse-transform consistency (round-trip through scaler)
-    try:
-        restored = scaler.inverse_transform(scaler.transform(X_forecast))
-        assert np.allclose(restored, X_forecast, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (predict)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (predict): {inv_err}")
+    # Note: Inverse-transform check removed - predict() now returns only target series,
+    # so full-series scaler cannot be used for validation
     
     # Predict with history parameter (using recent 60 periods)
     X_forecast_history, Z_forecast_history = model.predict(horizon=6, history=60)
     
-    print(f"   Forecast with history shape: {X_forecast_history.shape}")
-    print(f"   First forecast with history (target): {X_forecast_history[0, target_idx]:.6f}")
-    try:
-        restored_hist = scaler.inverse_transform(scaler.transform(X_forecast_history))
-        assert np.allclose(restored_hist, X_forecast_history, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (predict with history)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (history): {inv_err}")
+    print(f"   Forecast with history shape: {X_forecast_history.shape} (target series only)")
+    if X_forecast_history.shape[1] == 1:
+        print(f"   First forecast with history (target): {X_forecast_history[0, 0]:.6f}")
+    else:
+        print(f"   First forecast with history (targets): {X_forecast_history[0, :]}")
+    # Note: Inverse-transform check removed - predict() now returns only target series
     
 except ValueError as e:
     print(f"   Prediction failed: {e}")
@@ -340,17 +322,21 @@ try:
     
     # Simulate new data for nowcasting (in practice, this would be real-time data)
     # Use the last few periods of training data as "new" data
+    # Exclude date column for nowcasting
     n_new_periods = 5
-    X_new_raw = df_processed.iloc[-n_new_periods:].values
+    df_new_raw = df_processed.drop(columns=['date']).iloc[-n_new_periods:] if 'date' in df_processed.columns else df_processed.iloc[-n_new_periods:]
+    X_new_raw = df_new_raw.values
     
     # Option 1: Update scaler with new data (fit_transform on update batch)
+    # Use columns without date for scaler
+    data_cols = [col for col in df_processed.columns if col != 'date']
     update_pipeline = preprocessing_pipeline.clone().fit(
-        pd.DataFrame(X_new_raw, columns=df_processed.columns, index=df_processed.index[-n_new_periods:])
+        pd.DataFrame(X_new_raw, columns=data_cols, index=df_processed.index[-n_new_periods:])
     )
     X_new_std = update_pipeline.transform(
-        pd.DataFrame(X_new_raw, columns=df_processed.columns, index=df_processed.index[-n_new_periods:])
+        pd.DataFrame(X_new_raw, columns=data_cols, index=df_processed.index[-n_new_periods:])
     )
-    update_scaler = _get_fitted_scaler(update_pipeline, pd.DataFrame(X_new_raw, columns=df_processed.columns))
+    update_scaler = _get_fitted_scaler(update_pipeline, pd.DataFrame(X_new_raw, columns=data_cols))
     
     # Handle any NaN values (missing data in new observations)
     X_new_std = np.where(np.isfinite(X_new_std), X_new_std, np.nan)
@@ -360,44 +346,28 @@ try:
     
     # Update model state with new standardized data, then predict
     # Pattern: model.update(X_std).predict(horizon=1)
+    # predict() returns only target series (target=None uses DataModule's target_series)
     X_nowcast, Z_nowcast = model.update(X_new_std).predict(horizon=1)
     
-    # Extract nowcast for target series
-    target_idx = selected_cols.index(target_col)
-    nowcast_value = X_nowcast[0, target_idx]
+    # X_nowcast now contains only target series (no features)
+    if X_nowcast.shape[1] == 1:
+        nowcast_value = X_nowcast[0, 0]
+    else:
+        nowcast_value = X_nowcast[0, :]
     
     print(f"   Nowcast value for {target_col}: {nowcast_value:.6f}")
     print(f"   Nowcast uses VAR(1) factor dynamics")
-    try:
-        restored_now = scaler.inverse_transform(scaler.transform(X_nowcast))
-        assert np.allclose(restored_now, X_nowcast, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (nowcast, training scaler)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (nowcast): {inv_err}")
-    try:
-        restored_now_upd = update_scaler.inverse_transform(update_scaler.transform(X_nowcast))
-        assert np.allclose(restored_now_upd, X_nowcast, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (nowcast, update scaler)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (nowcast, update scaler): {inv_err}")
+    # Note: Inverse-transform check removed - predict() now returns only target series
     
     # Alternative: Update and predict separately
     model.update(X_new_std)
     X_nowcast2, Z_nowcast2 = model.predict(horizon=1)
-    nowcast_value2 = X_nowcast2[0, target_idx]
+    if X_nowcast2.shape[1] == 1:
+        nowcast_value2 = X_nowcast2[0, 0]
+    else:
+        nowcast_value2 = X_nowcast2[0, :]
     print(f"   Alternative pattern (separate calls): {nowcast_value2:.6f}")
-    try:
-        restored_now2 = scaler.inverse_transform(scaler.transform(X_nowcast2))
-        assert np.allclose(restored_now2, X_nowcast2, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (nowcast alt, training scaler)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (nowcast alt): {inv_err}")
-    try:
-        restored_now2_upd = update_scaler.inverse_transform(update_scaler.transform(X_nowcast2))
-        assert np.allclose(restored_now2_upd, X_nowcast2, atol=1e-6)
-        print("   ✔ Inverse-transform check passed (nowcast alt, update scaler)")
-    except Exception as inv_err:
-        print(f"   ⚠ Inverse-transform check failed (nowcast alt, update scaler): {inv_err}")
+    # Note: Inverse-transform check removed - predict() now returns only target series
     
 except (ValueError, AttributeError, IndexError) as e:
     print(f"   Nowcasting failed: {e}")
